From 072106a6169739156311ed71ca33890f27c35b85 Mon Sep 17 00:00:00 2001
From: zhongrj <646384940@qq.com>
Date: Sat, 11 Nov 2023 08:35:05 +0800
Subject: [PATCH] 公告调整为资讯

---
 src/main/java/org/springblade/modules/article/entity/ArticleCollectEntity.java |   18 ++++++++----------
 1 files changed, 8 insertions(+), 10 deletions(-)

diff --git a/src/main/java/org/springblade/modules/notice/entity/NoticeCollectEntity.java b/src/main/java/org/springblade/modules/article/entity/ArticleCollectEntity.java
similarity index 86%
rename from src/main/java/org/springblade/modules/notice/entity/NoticeCollectEntity.java
rename to src/main/java/org/springblade/modules/article/entity/ArticleCollectEntity.java
index c4154cd..8d8b9e4 100644
--- a/src/main/java/org/springblade/modules/notice/entity/NoticeCollectEntity.java
+++ b/src/main/java/org/springblade/modules/article/entity/ArticleCollectEntity.java
@@ -4,17 +4,17 @@
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
  *
- *  Redistributions of source code must retain the above copyright notice,
+ *  Redistributions of source code must retain the above copyright article,
  *  this list of conditions and the following disclaimer.
  *  Redistributions in binary form must reproduce the above copyright
  *  notice, this list of conditions and the following disclaimer in the
  *  documentation and/or other materials provided with the distribution.
  *  Neither the name of the dreamlu.net developer nor the names of its
  *  contributors may be used to endorse or promote products derived from
  *  this software without specific prior written permission.
  *  Author: Chill 庄骞 (smallchill@163.com)
  */
-package org.springblade.modules.notice.entity;
+package org.springblade.modules.article.entity;
 
 import com.baomidou.mybatisplus.annotation.IdType;
 import com.baomidou.mybatisplus.annotation.TableId;
@@ -22,15 +22,13 @@
 import com.fasterxml.jackson.annotation.JsonFormat;
 import com.fasterxml.jackson.databind.annotation.JsonSerialize;
 import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
-import lombok.Data;
 import io.swagger.annotations.ApiModel;
 import io.swagger.annotations.ApiModelProperty;
+import lombok.Data;
+import org.springframework.format.annotation.DateTimeFormat;
 
 import java.io.Serializable;
 import java.util.Date;
-import lombok.EqualsAndHashCode;
-import org.springblade.core.tenant.mp.TenantEntity;
-import org.springframework.format.annotation.DateTimeFormat;
 
 /**
  * 通知收藏表 实体类
@@ -39,9 +37,9 @@
  * @since 2023-11-08
  */
 @Data
-@TableName("jczz_notice_collect")
+@TableName("jczz_article_collect")
 @ApiModel(value = "NoticeCollect对象", description = "通知收藏表")
-public class NoticeCollectEntity implements Serializable {
+public class ArticleCollectEntity implements Serializable {
 
 	private static final long serialVersionUID = 1L;
 
@@ -57,7 +55,7 @@
 	 */
 	@ApiModelProperty(value = "收藏文章id")
 	@JsonSerialize(using = ToStringSerializer.class)
-	private Long noticeId;
+	private Long articleId;
 	/**
 	 * 收藏人id
 	 */
@@ -4,17 +4,17 @@
  *  this list of conditions and the following disclaimer.
  *  Redistributions in binary form must reproduce the above copyright
- *  notice, this list of conditions and the following disclaimer in the
+ *  article, this list of conditions and the following disclaimer in the
  *  documentation and/or other materials provided with the distribution.
  *  Neither the name of the dreamlu.net developer nor the names of its

--
Gitblit v1.9.3